/************************************************************************/
/*                                                                      */
/*             ,     ..        */
/*                   ,   ,   .               */
/*                                                                      */
/************************************************************************/

#include <htc.h>
#include "i2c.h"

/************************************************************************/
/* Standard I2C bus routines                                            */
/************************************************************************/

// Waits until I2C module is in idle state.
void i2c_idle(void)
{
	// wait until I2C bus is inactive
    while (SEN || PEN || RSEN || RCEN || ACKEN || RW);
}

// Initiates I2C bus start condition.
void i2c_start(void)
{
	// initiate I2C bus start condition
	SEN = 1;
	// wait until I2C bus is inactive
	i2c_idle();
}

// Initiates I2C bus restart condition.
void i2c_restart(void)
{
	// initiate I2C bus start condition
	RSEN = 1;
	// wait until I2C bus is inactive
	i2c_idle();
}

// Initiates I2C bus stop condition.
void i2c_stop(void)
{
	// initiate I2C bus stop condition
	PEN = 1;
	// wait until I2C bus is inactive
	i2c_idle();
}

// Initiates I2C bus acknowledge sequence.
void i2c_ack()
{
	// acknowledge
	ACKDT = 0;
	// initiate acknowledge sequence
	ACKEN = 1;
	// wait until I2C bus is inactive
	i2c_idle();
}	

// Initiates I2C bus NOT-acknowledge sequence.
void i2c_nack()
{
	// NOT acknowledge
	ACKDT = 1;
	// initiate acknowledge sequence
	ACKEN = 1;
	// wait until I2C bus is inactive
	i2c_idle();
}	

// Writes single byte to I2C bus.
// Returns 1 if ACK is received, 0 otherwise.
int i2c_write(unsigned char data)
{
	// initiate I2C bus write condition,
	// write data
	SSPBUF = data;
	// wait until write cycle is complete
	while (BF);
	// wait until I2C bus is inactive
	i2c_idle();
	// test for acknowledge from EEPROM
	if (ACKSTAT) return 0;
	return 1;
}
	
// Reads single byte from I2C bus.
// Returns the byte read.
unsigned char i2c_read(void)
{
	// generate receive condition
	RCEN = 1;
	// wait until receive is complete
	while (RCEN);
	// read received byte
	return SSPBUF;
}
