/************************************************************************/
/*                                                                      */
/*             ,     ..        */
/*                   ,   ,   .               */
/*                                                                      */
/************************************************************************/

/************************************************************************/
/* IR receiver support                                                  */
/************************************************************************/

// IR code bit count
#define RCV_DATA_BITS					32
// Times are in microseconds
#define RCV_DEF_HD_SPACE_TIME_MIN		8900l
#define RCV_DEF_HD_SPACE_TIME_MAX		9100l
#define RCV_DEF_HD_MARK_TIME_MIN		4300l
#define RCV_DEF_HD_MARK_TIME_MAX		4700l
#define RCV_DEF_DT_PAUSE_TIME_MIN		500l
#define RCV_DEF_DT_PAUSE_TIME_MAX		700l
#define RCV_DEF_DT_0_TIME_MIN			350l
#define RCV_DEF_DT_0_TIME_MAX			600l
#define RCV_DEF_DT_1_TIME_MIN			1500l
#define RCV_DEF_DT_1_TIME_MAX			1700l


// Used to store min and max time
typedef struct TimeBounds
{
	char tmin;
	char tmax;
} TimeBounds;

// IR receiver configuration
typedef struct IR_RcvConfig
{
	char data_bits;
	char hd_tmr_scale;
	struct TimeBounds hd_space_time;
	struct TimeBounds hd_mark_time;
	char dt_tmr_scale;
	struct TimeBounds dt_pause_time;
	struct TimeBounds dt_0_time;
	struct TimeBounds dt_1_time;
} IR_RcvConfig;

// IR receiver states
typedef enum IR_ReceiverState
{
	rcvstIdle,
	rcvstHdSpace,
	rcvstHdMark,
	rcvstDtSpace,
	rcvstDtMark,
	rcvstTerm
} IR_ReceiverState;

// Global IR variables
extern IR_RcvConfig g_rcvcfg;
extern unsigned long g_rcvcode;
extern char g_iscode;

// Function prototypes
void IR_SetDefConfig(void);
void IR_Init(void);
void IR_HandleInterrupt();
